@@ -148,7 +148,8 @@ static void esorex_json_parameterlist(void)
         whole_file = cpl_malloc(length+1);
         
         cpl_test_nonnull(whole_file);
-        (void) fread(whole_file, 1, length, fjson);
+        int read_length = fread(whole_file, 1, length, fjson);
+        cpl_test_eq(read_length, length);
         whole_file[length]='\0';
         fclose(fjson);
         
@@ -186,7 +187,8 @@ static void esorex_json_parameterlist(void)
         whole_file = cpl_malloc(length+1);
         
         cpl_test_nonnull(whole_file);
-        (void) fread(whole_file, 1, length, fjson);
+        int read_length = fread(whole_file, 1, length, fjson);
+        cpl_test_eq(read_length, length);
         whole_file[length]='\0';
         fclose(fjson);
         
@@ -283,7 +285,8 @@ static void esorex_json_parameterlist(void)
         whole_file = cpl_malloc(length+1);
 
         cpl_test_nonnull(whole_file);
-        (void) fread(whole_file, 1, length, fjson);
+        int read_length = fread(whole_file, 1, length, fjson);
+        cpl_test_eq(read_length, length);
         whole_file[length]='\0';
         fclose(fjson);
 
@@ -381,7 +384,8 @@ static void esorex_json_frameset(void)
         whole_file = cpl_malloc(length+1);
         
         cpl_test_nonnull(whole_file);
-        (void) fread(whole_file, 1, length, fjson);
+        int read_length = fread(whole_file, 1, length, fjson);
+        cpl_test_eq(read_length, length);
         whole_file[length]='\0';
         fclose(fjson);
         
@@ -428,7 +432,8 @@ static void esorex_json_frameset(void)
         whole_file = cpl_malloc(length+1);
 
         cpl_test_nonnull(whole_file);
-        (void) fread(whole_file, 1, length, fjson);
+        int read_length = fread(whole_file, 1, length, fjson);
+        cpl_test_eq(read_length, length);
         whole_file[length]='\0';
         fclose(fjson);
 
